summaryrefslogtreecommitdiff
path: root/libpod/container_api.go
diff options
context:
space:
mode:
Diffstat (limited to 'libpod/container_api.go')
-rw-r--r--libpod/container_api.go11
1 files changed, 9 insertions, 2 deletions
diff --git a/libpod/container_api.go b/libpod/container_api.go
index 3693ab78b..72df60eb8 100644
--- a/libpod/container_api.go
+++ b/libpod/container_api.go
@@ -694,8 +694,9 @@ func (c *Container) Wait() (int32, error) {
return exitCode, nil
}
-// CleanupStorage unmounts all mount points in container and cleans up container storage
-func (c *Container) CleanupStorage() error {
+// Cleanup unmounts all mount points in container and cleans up container storage
+// It also cleans up the network stack
+func (c *Container) Cleanup() error {
if !c.locked {
c.lock.Lock()
defer c.lock.Unlock()
@@ -703,6 +704,12 @@ func (c *Container) CleanupStorage() error {
return err
}
}
+
+ // Stop the container's network namespace (if it has one)
+ if err := c.cleanupNetwork(); err != nil {
+ logrus.Errorf("unable cleanup network for container %s: %q", c.ID(), err)
+ }
+
return c.cleanupStorage()
}